function curr=fotodiodo(luz)
%======================================================
% FOTODIODO
%    Esta funcion permite expresar la entrada optica en forma de corriente.
%O sea, llevar la entrada a un nivel electrico.
%                             
%           Sigue la siguiente ecuacion:
%
%                               I (mA)=R*M*Pot_Rec
%         
%           Donde:  Pot_Rec  (mW)  = Potencia que llega al fotodetector.Depende del tipo de senal y 
%                                                    de la longitud de onda.
%                        R  (mW/mA)     = Responsividad del Fotodetector. Depende del tipo de material
%                                                    de que este hecho el fotodetector. 
%                        M                      = Factor de Multiplicacion de un fotodiodo APD.
%                                                     Se denomina Ganancia APD Promedio.
%                                                                                    
%======================================================
%
%	AUTORES : Z. AGUI%O & D. STECKLER
%                       Universidad de Carabobo
%                       Valencia edo. Carabobo, VENEZUELA
%
%	FECHA     : Enero 2004
%	VERSION : 1.0
%
%======================================================
%	Realizado bajo MATLAB 6.5 Release 13/ Enero 2004 (DZ)
%======================================================
%Obtencion de Parameros del Bloque
i=1; band=0;
if band==0
    while i<=50
        if isempty(find_system(gcs,'Name','Fotodetector'))==1
            band=2; %No Encontrado
        else
            band=3;  %Encontrado
            Bl=([gcs,'/','Fotodetector']);  
            break
        end
        i=i+1;
    end
else %Entra solo si no encontro el nombre 'Laser'
    i=1;
    while i<=50
        if isempty(find_system(gcs,'Name',['Fotodetector',int2str(i)]))==1
            band=3;% No Encontrado
        else
            band=4; %Encontrado
            Bl=([gcs,'/','Fotodetector',int2str(i)]);  
            break
        end
        i=i+1;
    end
end
%
%
R=str2num(get_param(Bl,'R'));
M=str2num(get_param(Bl,'M'));
%
%Inicializacion de Variables
[a b]=size(luz);
Is=zeros(a,b);
curr=zeros(a,b);
%
%======================================================
%
%Calculo dependiendo de los parametros obtenidos
%
R_APD=M*R;
for i=1:b
    Is(1,i)=R_APD*luz(1,i); %luz(:,:)=Pot_Rec;
end
%
curr=Is(:,:);
end
% [EOF] fotodiodo.m