function luz=laser(u)
%======================================================
% LASER
%    Esta funcion permite expresar la entrada electrica en forma de potencia optica.
%O sea, llevar la entrada a un nivel optico (luz).
%                             
%           Sigue la siguiente ecuacion:
%
%                               Pot_Emit (mW) = (hw/2q)(Nd)(I-Ith) =  Nd(I-Ith)
%         
%           Donde:  hw/2q (eV)       = 1 (Ref. SERWAY. Fisica Tomo II. McGraw Hill. Mexico,1997.)
%                        Nd  (mW/mA)  = Eficiencia del Laser. Depende del material.
%                        Ith  (mA)          = Corriente Umbral. Depende de la Temperatura y del Material.
%                                                    Sigue la sig. ecuacion:
%                                                                                    Ith=Io*e^(T/To)
%
%======================================================
%
%	AUTORES : Z. AGUI%O & D. STECKLER
%                       Universidad de Carabobo
%                       Valencia edo. Carabobo, VENEZUELA
%
%	FECHA     : Enero 2004
%	VERSION : 1.0
%
%======================================================
%	Realizado bajo MATLAB 6.5 Release 13/ Enero 2004 (DZ)
%======================================================
%
%Obtencion de Parameros del Bloque
i=1; band=0;

    while i<=50
        if isempty(find_system(gcs,'Name','Laser'))==1
            
            if isempty(find_system(gcs,'Name',['Laser',int2str(i)]))==1
                band=2;% No Encontrado
            else
                band=3; %Encontrado
                BloqueLaser=([gcs,'/','Laser',int2str(i)]);
                tiposenal=get_param(BloqueLaser,'sel');
                frecuencia=get_param(BloqueLaser,'frec');
                break
            end
            
        else
            
            band=4;  %Encontrado
            BloqueLaser=([gcs,'/','Laser']);
            tiposenal=get_param(BloqueLaser,'sel');
            frecuencia=get_param(BloqueLaser,'frec');
            break
            
        end
        i=i+1;
    end

%
%Inicializacion de Variables
[a b]=size(u);
Pot=zeros(a,b);
luz=zeros(a,b);
Nd=0;%Esta tomara valores tipicos dependiendo del tipo de laser.
Ith=0;% Corriente Threshold, tomara valores tipicos.
%
%
%======================================================
%
%Calculo dependiendo de los parametros obtenidos
%
switch (tiposenal)
    
case 'STS-12/STM-4'  %622 Mbps
    switch (frecuencia)
        case '1310'
            Nd=0.5;
            Ith= 0.01;
        case '1550'
            Nd=0.25;
            Ith= 0.01;
    end
    
case 'STS-48/STM-16'   %2.5 Gbps
    switch (frecuencia)
        case '1310'
            Nd=0.25;
            Ith= 0.01;
        case '1550'
            Nd=0.22;
            Ith= 0.01;
    end
    
 case 'STS-192/STM-64'   %10 Gbps
     switch (frecuencia)
        case '1310'
            Nd=0.25;
            Ith= 0.009;
        case '1550'
            %Datasheet LUCENT
            Nd=0.2;
            Ith= 0.015;
    end

 case 'STS-768/STM-256'   %40 Gbps
    switch (frecuencia)
        case '1310'
            Nd=0.25;
            Ith= 0.009;
        case '1550'
            Nd=0.2;
            Ith= 0.015;
    end
    
end

for j=1:b
    Pot(1,j)=Nd*(u(1,j)-Ith); %u(:,:)=Iop;
end

luz=Pot(:,:);


% [EOF] laser.m